=begin

  Copyright (C) 2013 Keisuke Nishida

  Licensed to the Apache Software Foundation (ASF) under one
  or more contributor license agreements.  See the NOTICE file
  distributed with this work for additional information
  regarding copyright ownership.  The ASF licenses this file
  to you under the Apache License, Version 2.0 (the
  "License"); you may not use this file except in compliance
  with the License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing,
  software distributed under the License is distributed on an
  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  KIND, either express or implied.  See the License for the
  specific language governing permissions and limitations
  under the License.

=end

require 'fluent/plugin/out_s3'

module Fluent

class RamblerOutput < S3Output
  Plugin.register_output('rambler', self)

  config_param :columns, :string, :default => '%{time}'
  config_param :time_format, :string, :default => '%Y-%m-%d %H:%M:%S'
  config_param :s3_object_key_format, :string, :default => '%{path}%{time_slice}/%{index}.%{file_extension}'

  def initialize
    super
  end

  def configure(conf)
    super

    unless ['gzip', 'txt'].include? @store_as
      raise ConfigError, "only 'gzip' or 'txt' is allowed for store_as: #{@store_as}"
    end

    @separator = '|'
    @columns = @columns.split(@separator)
  end

  def format(tag, time, record)
    super

    @columns.map {|name|
      if name == '%{time}'
        # timestamp
        if @localtime
          Time.at(time).strftime(@time_format)
        else
          Time.at(time).utc.strftime(@time_format)
        end
      else
        # record value
        record[name].to_s
      end
    }.join(@separator) + "\n"
  end
end

end
